@@ -107,11 +107,15 @@ class Pg:
         await self.pool.execute(f"DELETE FROM {self.table} WHERE {' AND '.join(f'{c} = ${i}' for i, c in enums)}", *opt.values())
 
 
+
     async def add(self, **opt):
         one_column = f"{list(opt.keys())[0]} = array_append({list(opt.keys())[0]}, $1)"
         enums = enumerate(opt.keys(), 1)
         columns = ' AND '.join(f'{c} = ${i}' for i, c in enums if i != 1) 
 
+        if columns is None:
+            return await self.pool.execute(f'UPDATE {self.table} SET {one_column}', *opt.values())
+
         await self.pool.execute(f'UPDATE {self.table} SET {one_column} WHERE {columns}', *opt.values())
 
     
